extends Sprite2D
class_name Board

const BOARD_SIZE = 8
const CELL_WIDTH = 18

# piece textures
const BLACK_BISHOP = preload("res://assets/temp_assets/black_bishop.png")
const BLACK_KING = preload("res://assets/temp_assets/black_king.png")
const BLACK_KNIGHT = preload("res://assets/temp_assets/black_knight.png")
const BLACK_PAWN = preload("res://assets/temp_assets/black_pawn.png")
const BLACK_QUEEN = preload("res://assets/temp_assets/black_queen.png")
const BLACK_ROOK = preload("res://assets/temp_assets/black_rook.png")
const WHITE_BISHOP = preload("res://assets/temp_assets/white_bishop.png")
const WHITE_KING = preload("res://assets/temp_assets/white_king.png")
const WHITE_KNIGHT = preload("res://assets/temp_assets/white_knight.png")
const WHITE_PAWN = preload("res://assets/temp_assets/white_pawn.png")
const WHITE_QUEEN = preload("res://assets/temp_assets/white_queen.png")
const WHITE_ROOK = preload("res://assets/temp_assets/white_rook.png")

const TEXTURE_HOLDER = preload("res://scenes/texture_holder.tscn")

@onready var pieces: Node2D = $Pieces
@onready var dots: Node2D = $Dots

# Variables
var board: Array
var white: bool
var state: bool
var moves = []
var selected_piece: Vector2

# Called when the node enters the scene tree for the first time.
func _ready() -> void:
	board.append([4,2,3,5,6,3,2,4])
	board.append([1,1,1,1,1,1,1,1])
	board.append([0,0,0,0,0,0,0,0])
	board.append([0,0,0,0,0,0,0,0])
	board.append([0,0,0,0,0,0,0,0])
	board.append([0,0,0,0,0,0,0,0])
	board.append([-1,-1,-1,-1,-1,-1,-1,-1])
	board.append([-4,-2,-3,-5,-6,-3,-2,-4])
	
	display_board()
	
func _input(event):
	if (event is InputEventMouseButton && event.pressed):
		if (event.button_index == MOUSE_BUTTON_LEFT):
			if is_mouse_out():
				return
			
			var mouse_position: Vector2 = get_global_mouse_position()
			var x_click = snapped(mouse_position.x, 0) / CELL_WIDTH
			var y_click = abs(snapped(mouse_position.y, 0)) / CELL_WIDTH
			
			print(x_click, y_click)

# Checks if mouse input is on the board
func is_mouse_out() -> bool:
	var mouse_position: Vector2 = get_global_mouse_position()
	
	if (mouse_position.x < 0 || mouse_position.x > 144 || mouse_position.y > 0 || mouse_position.y < -144):
		return true
	
	return false

# Displays board and instantiates "piece holders"
func display_board() -> void:
	for i in BOARD_SIZE:
		for j in BOARD_SIZE:
			# Instantiate texture holders, scene that holds pieces
			var holder = TEXTURE_HOLDER.instantiate()
			pieces.add_child(holder)
			holder.global_position = Vector2(j * CELL_WIDTH + (CELL_WIDTH / 2), -i * CELL_WIDTH - (CELL_WIDTH / 2))
			
			# Looks at board array and matches pieces with its respective value
			match board[i][j]:
				-6: holder.texture = BLACK_KING
				-5: holder.texture = BLACK_QUEEN
				-4: holder.texture = BLACK_ROOK
				-3: holder.texture = BLACK_BISHOP
				-2: holder.texture = BLACK_KNIGHT
				-1: holder.texture = BLACK_PAWN
				0: holder.texture = null
				6: holder.texture = WHITE_KING
				5: holder.texture = WHITE_QUEEN
				4: holder.texture = WHITE_ROOK
				3: holder.texture = WHITE_BISHOP
				2: holder.texture = WHITE_KNIGHT
				1: holder.texture = WHITE_PAWN
